@@ -1,6 +1,6 @@
 package Mango::BSON::Binary;
 use Mojo::Base -base;
-use overload '""' => sub { shift->data }, fallback => 1;
+use overload bool => sub {1}, '""' => sub { shift->data }, fallback => 1;
 
 use Mojo::Util 'b64_encode';
 
@@ -21,11 +21,13 @@ Mango::BSON::Binary - Binary type
   use Mango::BSON::Binary;
 
   my $bin = Mango::BSON::Binary->new(data => $bytes, type => 'generic');
+  say $bin->data;
 
 =head1 DESCRIPTION
 
 L<Mango::BSON::Binary> is a container for the BSON binary type used by
-L<Mango::BSON>.
+L<Mango::BSON>. For C<JSON> implementations like L<Mojo::JSON>, that support
+the C<TO_JSON> method, it will automatically C<Base64> encode the binary data.
 
 =head1 ATTRIBUTES
 
@@ -49,6 +51,22 @@ Binary subtype.
 
 L<Mango::BSON::Binary> inherits all methods from L<Mojo::Base>.
 
+=head1 OPERATORS
+
+L<Mango::BSON::Binary> overloads the following operators.
+
+=head2 bool
+
+  my $bool = !!$bin;
+
+Always true.
+
+=head2 stringify
+
+  my $str = "$bin";
+
+Alias for L</data>.
+
 =head1 SEE ALSO
 
 L<Mango>, L<Mojolicious::Guides>, L<http://mojolicio.us>.
